<?php

namespace Drupal\calculation_fields\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a calculation_fields form.
 */
class ExampleForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'calculation_fields_example';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['first_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First value'),
      '#required' => TRUE,
    ];

    $form['second_value'] = [
      '#type' => 'number',
      '#title' => $this->t('SEcond value'),
      '#required' => TRUE,
      '#min' => 0,
      '#max' => 2000,
    ];

    $form['third_value'] = [
      '#type' => 'number',
      '#title' => $this->t('third value'),
      '#required' => TRUE,
      '#min' => 0,
      '#max' => 2000,
    ];

    $form['multiple'] = [
      '#type' => 'select',
      '#title' => $this->t('Multiple'),
      '#options' => [
        1 => 1,
        2 => 2,
        3 => 3,
      ],
      '#required' => TRUE,
      '#min' => 0,
      '#max' => 2000,
    ];

    $form['result'] = [
      '#type' => 'form_element_math',
      '#title' => $this->t('Result'),
      '#required' => TRUE,
      '#evaluation_fields' => '(:first_value + :second_value + :third_value) * :multiple'
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (mb_strlen($form_state->getValue('message')) < 10) {
      $form_state->setErrorByName('message', $this->t('Message should be at least 10 characters.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->messenger()->addStatus($this->t('The message has been sent.'));
    $form_state->setRedirect('<front>');
  }

}
